@@ -1,6 +1,7 @@
+from nicegui import background_tasks
+
 from . import analysis, automation, driving, event, geometry, hardware, pathplanning, persistence, run, system, vision
 from .config import Config
 from .rosys import (NEW_NOTIFICATION, Notification, config, is_test, notify, on_repeat, on_shutdown, on_startup,
                     reset_after_test, reset_before_test, set_time, shutdown, sleep, startup, time, uptime)
 from .simulation_ui import simulation_ui
-from .task_logger import create_task
