@@ -1,14 +1,12 @@
 from .asyncio_warnings import AsyncioWarnings
 from .kpi_buckets import Day, Month, TimeBucket, Week
 from .kpi_logger import KpiLogger, date_to_str, str_to_date
-from .kpi_page_ import KpiPage as kpi_page
+from .kpi_page_ import kpi_page
 from .legacy.asyncio_monitor import AsyncioMonitor
 from .legacy.network_monitor import NetworkMonitor, NetworkStats
+from .legacy.objgraph_page import objgraph_page
+from .memory import MemoryMiddleware
+from .profile_button_ import ProfileButton as profile_button
 from .timelapse_recorder import TimelapseRecorder
 from .track import track
 from .videos_page_ import VideosPage as videos_page
-
-try:
-    from .profile_button_ import ProfileButton as profile_button
-except:
-    pass
