@@ -1,7 +1,8 @@
 import psutil
 from nicegui import ui
 from nicegui.elements.chart import Chart
-from rosys import config
+
+from ...rosys import config
 
 
 class CpuUsage(Chart):
