@@ -2,15 +2,11 @@ from functools import wraps
 
 from nicegui import ui
 
-from .. import rosys
-
 
 class Track:
 
     def __init__(self) -> None:
         self.stack: list[str] = []
-        self._labels: list[ui.label] = []
-        rosys.on_repeat(self.update, 0.5)
 
     def __call__(self, f):
         @wraps(f)
@@ -23,17 +19,13 @@ class Track:
                     self.stack.pop()
         return wrap
 
-    def update(self) -> None:
-        for label in self._labels:
-            label.text = ' → '.join(self.stack)
-
     def ui(self) -> ui.label:
-        self._labels.append(ui.label())
-        return self._labels[-1]
+        label = ui.label()
+        ui.timer(0.5, lambda: label.set_text(' → '.join(self.stack)))
+        return label
 
     def reset(self) -> None:
         self.stack.clear()
-        self.update()
 
 
 track = Track()
