@@ -5,7 +5,10 @@ from .automator import Automator
 
 
 class AutomationControls:
-    '''This UI element contains start/stop/pause/resume buttons for controlling a given automator.'''
+    '''This UI element contains start/stop/pause/resume buttons for controlling a given automator.
+
+    See [Play-pause-stop](https://rosys.io/examples/play-pause-stop/) for a simple example of the automation controls.
+    '''
 
     def __init__(self, automator: Automator) -> None:
         play_button = ui.button(on_click=lambda: automator.start()) \
@@ -27,6 +30,7 @@ class AutomationControls:
         ui.timer(config.ui_update_interval, refresh)
 
     def _disable(self, button: ui.button, should_disable: bool) -> None:
-        if getattr(button.view, 'disable', False) != should_disable:
-            button.view.disable = should_disable
-            button.update()
+        if should_disable:
+            button.props('disable')
+        else:
+            button.props(remove='disable')
