@@ -6,7 +6,10 @@ import logging
 from dataclasses import dataclass
 from typing import Awaitable, Callable
 
-from . import task_logger
+from nicegui import globals as nicegui_globals
+
+from rosys import background_tasks
+
 from .helpers import invoke
 
 startup_coroutines: list[Awaitable] = []
@@ -37,8 +40,21 @@ class Event:
         self.listeners.append(EventListener(callback=callback, filepath=frame.f_code.co_filename, line=frame.f_lineno))
         return self
 
+    def register_ui(self, callback: Callable) -> Event:
+        self.register(callback)
+        client = nicegui_globals.get_client()
+        if not client.shared:
+            async def register_disconnect():
+                try:
+                    await client.connected()
+                    client.on_disconnect(lambda: self.unregister(callback))
+                except TimeoutError:
+                    self.unregister(callback)
+            background_tasks.create(register_disconnect())
+        return self
+
     def unregister(self, callback: Callable) -> None:
-        self.listeners[:] = [l for l in self.listeners if l.callback == callback]
+        self.listeners[:] = [l for l in self.listeners if l.callback != callback]
 
     async def call(self, *args) -> None:
         '''Fires event and waits async until all registered listeners are completed'''
@@ -57,7 +73,7 @@ class Event:
                 if isinstance(result, Awaitable):
                     if loop.is_running:
                         name = f'{listener.filepath}:{listener.line}'
-                        tasks.append(task_logger.create_task(result, name=name, loop=loop))
+                        tasks.append(background_tasks.create(result, name=name, loop=loop))
                     else:
                         startup_coroutines.append(result)
             except:
