@@ -1,14 +1,15 @@
 #!/usr/bin/env python3
-from nicegui import ui
-import pylab as pl
-import numpy as np
 import time
-from rosys.world import Point
-from rosys.pathplanning.grid import Grid
-from rosys.pathplanning.robot_renderer import RobotRenderer
-from rosys.pathplanning.obstacle_map import ObstacleMap
+
+import numpy as np
+import pylab as pl
+from nicegui import ui
+from rosys.geometry import Point
+from rosys.pathplanning import plot_tools as pt
 from rosys.pathplanning.distance_map import DistanceMap
-import rosys.pathplanning.plot_tools as pt
+from rosys.pathplanning.grid import Grid
+from rosys.pathplanning.obstacle_map import ObstacleMap
+from rosys.pathplanning.robot_renderer import RobotRenderer
 
 grid = Grid((60, 80, 36), (0, 0, 16.0, 12.0))
 obstacles = [
