@@ -8,9 +8,8 @@ from typing import Any, Optional
 import cv2
 import numpy as np
 import PIL
-import rosys
 
-from .. import persistence
+from .. import persistence, rosys
 from ..geometry import Rectangle
 from .camera_provider import CameraProvider
 from .image import Image, ImageSize
@@ -28,6 +27,7 @@ class Device:
     exposure_min: int = 0
     exposure_max: int = 0
     exposure_default: int = 0
+    has_manual_exposure: bool = False
     last_state: dict = field(default_factory=dict)
     video_formats: set[str] = field(default_factory=set)
 
@@ -111,7 +111,7 @@ class UsbCameraProviderHardware(CameraProvider):
                 if device.capture is None:
                     await self.activate(uid)
                 if device.capture is None:
-                    self.log.warn(f'unexpected missing capture handle for {uid}')
+                    self.log.warning(f'unexpected missing capture handle for {uid}')
                     continue
                 image = await rosys.run.io_bound(self.capture_image, uid)
                 if image is None:
@@ -132,8 +132,7 @@ class UsbCameraProviderHardware(CameraProvider):
     async def update_parameters(self) -> None:
         for uid, camera in self._cameras.items():
             if camera.active and uid in self.devices:
-                continue
-            await rosys.run.io_bound(self.set_parameters, camera, self.devices[uid])
+                await rosys.run.io_bound(self.set_parameters, camera, self.devices[uid])
 
     def capture_image(self, id) -> Any:
         _, image = self.devices[id].capture.read()
@@ -148,6 +147,7 @@ class UsbCameraProviderHardware(CameraProvider):
         self.devices[uid].capture = capture
         await rosys.run.io_bound(self.set_parameters, camera, device)
         self.log.info(f'activated {uid}')
+        await self.CAMERA_ADDED.call(camera)
 
     async def deactivate(self, camera: UsbCamera) -> None:
         if camera.id not in self.devices:
@@ -226,18 +226,19 @@ class UsbCameraProviderHardware(CameraProvider):
             self.log.info(f'updating resolution of {camera.id} from {resolution} to {camera.resolution}')
             device.capture.set(cv2.CAP_PROP_FRAME_WIDTH, camera.resolution.width)
             device.capture.set(cv2.CAP_PROP_FRAME_HEIGHT, camera.resolution.height)
-        auto_exposure = device.capture.get(cv2.CAP_PROP_AUTO_EXPOSURE) == 3
-        if camera.auto_exposure and not auto_exposure:
-            self.log.info(f'activating auto-exposure for {camera.id}')
-            device.capture.set(cv2.CAP_PROP_AUTO_EXPOSURE, 3)  # `v4l2-ctl -L` says "3: Aperture Priority Mode"
-        if auto_exposure and not camera.auto_exposure:
-            self.log.info(f'deactivating auto-exposure of {camera.id}')
-            device.capture.set(cv2.CAP_PROP_AUTO_EXPOSURE, 1)  # `v4l2-ctl -L` says "1: Manual Mode"
-        if not camera.auto_exposure and device.exposure_max > 0:
-            exposure = device.capture.get(cv2.CAP_PROP_EXPOSURE) / device.exposure_max
-            if camera.exposure is not None and camera.exposure != exposure:
-                self.log.info(f'updating exposure of {camera.id} from {exposure} to {camera.exposure})')
-                device.capture.set(cv2.CAP_PROP_EXPOSURE, int(camera.exposure * device.exposure_max))
+        if device.has_manual_exposure:
+            auto_exposure = device.capture.get(cv2.CAP_PROP_AUTO_EXPOSURE) == 3
+            if camera.auto_exposure and not auto_exposure:
+                self.log.info(f'activating auto-exposure for {camera.id}')
+                device.capture.set(cv2.CAP_PROP_AUTO_EXPOSURE, 3)  # `v4l2-ctl -L` says "3: Aperture Priority Mode"
+            if auto_exposure and not camera.auto_exposure:
+                self.log.info(f'deactivating auto-exposure of {camera.id}')
+                device.capture.set(cv2.CAP_PROP_AUTO_EXPOSURE, 1)  # `v4l2-ctl -L` says "1: Manual Mode"
+            if not camera.auto_exposure and device.exposure_max > 0:
+                exposure = device.capture.get(cv2.CAP_PROP_EXPOSURE) / device.exposure_max
+                if camera.exposure is not None and camera.exposure != exposure:
+                    self.log.info(f'updating exposure of {camera.id} from {exposure} to {camera.exposure})')
+                    device.capture.set(cv2.CAP_PROP_EXPOSURE, int(camera.exposure * device.exposure_max))
 
     async def load_value_ranges(self, device: Device) -> None:
         output = await self.run_v4l(device, '--all')
@@ -245,9 +246,12 @@ class UsbCameraProviderHardware(CameraProvider):
             return
         match = re.search(r'exposure_absolute.*: min=(\d*).*max=(\d*).*default=(\d*).*', output)
         if match is not None:
+            device.has_manual_exposure = True
             device.exposure_min = int(match.group(1))
             device.exposure_max = int(match.group(2))
             device.exposure_default = int(match.group(3))
+        else:
+            device.has_manual_exposure = False
         output = await self.run_v4l(device, '--list-formats')
         match = re.finditer(r"$.*'(.*)'.*", output)
         for m in match:
